@@ -31,8 +31,9 @@ function(object,x,y,test.x,test.y=NULL, n.iter,...){
   if(test.dat)
     test.y<-c(-1,1)[as.numeric(as.factor(test.y))]
   control=as.list(object$model$trees[[1]]$control)
+  na.action=object$na.action
   lossObj=object$model$lossObj
-  result= result =ada.machine(x,ny,test.x,test.y,n.iter,lossObj=lossObj,oldObj=object,control=control)
+  result =ada.machine(x,ny,test.x,test.y,n.iter,lossObj=lossObj,oldObj=object,control=control,na.action=na.action)
   g=as.factor(lev[as.numeric(as.factor(sign(result$F[[1]])))])
   tab=table(as.factor(y),g,dnn=c("True value","Final Prediction"))
   obj=structure(list(model=result,fit=g,call=object$call,confusion=tab,iter=n.iter,
